@@ -10,6 +10,9 @@ A role containing Fixflo utilities.
 
 =cut
 
+use strict;
+use warnings;
+
 use Moo::Role;
 
 =head1 METHODS
